Documentation
¶
Index ¶
- Constants
- Variables
- func Kind(kind string) schema.GroupKind
- func RegisterDeepCopies(scheme *runtime.Scheme) errordeprecated
- func Resource(resource string) schema.GroupResource
- type Client
- type DeploymentController
- type DeploymentHandlerFunc
- type DeploymentInterface
- type DeploymentLifecycle
- type DeploymentList
- type DeploymentLister
- type DeploymentsGetter
- type Interface
Constants ¶
const ( GroupName = "apps" Version = "v1beta2" )
Variables ¶
var ( DeploymentGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "Deployment", } DeploymentResource = metav1.APIResource{ Name: "deployments", SingularName: "deployment", Namespaced: true, Kind: DeploymentGroupVersionKind.Kind, } )
var ( SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: Version}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func RegisterDeepCopies
deprecated
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type Client ¶
func (*Client) Deployments ¶
func (c *Client) Deployments(namespace string) DeploymentInterface
func (*Client) RESTClient ¶
type DeploymentController ¶
type DeploymentController interface {
Informer() cache.SharedIndexInformer
Lister() DeploymentLister
AddHandler(name string, handler DeploymentHandlerFunc)
AddClusterScopedHandler(name, clusterName string, handler DeploymentHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type DeploymentHandlerFunc ¶
type DeploymentHandlerFunc func(key string, obj *v1beta2.Deployment) error
func NewDeploymentLifecycleAdapter ¶
func NewDeploymentLifecycleAdapter(name string, clusterScoped bool, client DeploymentInterface, l DeploymentLifecycle) DeploymentHandlerFunc
type DeploymentInterface ¶
type DeploymentInterface interface {
ObjectClient() *clientbase.ObjectClient
Create(*v1beta2.Deployment) (*v1beta2.Deployment, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1beta2.Deployment, error)
Get(name string, opts metav1.GetOptions) (*v1beta2.Deployment, error)
Update(*v1beta2.Deployment) (*v1beta2.Deployment, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*DeploymentList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() DeploymentController
AddHandler(name string, sync DeploymentHandlerFunc)
AddLifecycle(name string, lifecycle DeploymentLifecycle)
AddClusterScopedHandler(name, clusterName string, sync DeploymentHandlerFunc)
AddClusterScopedLifecycle(name, clusterName string, lifecycle DeploymentLifecycle)
}
type DeploymentLifecycle ¶
type DeploymentLifecycle interface {
Create(obj *v1beta2.Deployment) (*v1beta2.Deployment, error)
Remove(obj *v1beta2.Deployment) (*v1beta2.Deployment, error)
Updated(obj *v1beta2.Deployment) (*v1beta2.Deployment, error)
}
type DeploymentList ¶
type DeploymentList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1beta2.Deployment
}
func (*DeploymentList) DeepCopy ¶
func (in *DeploymentList) DeepCopy() *DeploymentList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DeploymentList.
func (*DeploymentList) DeepCopyInto ¶
func (in *DeploymentList) DeepCopyInto(out *DeploymentList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*DeploymentList) DeepCopyObject ¶
func (in *DeploymentList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type DeploymentLister ¶
type DeploymentLister interface {
List(namespace string, selector labels.Selector) (ret []*v1beta2.Deployment, err error)
Get(namespace, name string) (*v1beta2.Deployment, error)
}
type DeploymentsGetter ¶
type DeploymentsGetter interface {
Deployments(namespace string) DeploymentInterface
}
type Interface ¶
type Interface interface {
RESTClient() rest.Interface
controller.Starter
DeploymentsGetter
}
Click to show internal directories.
Click to hide internal directories.