Documentation
¶
Index ¶
- Constants
- Variables
- func Kind(kind string) schema.GroupKind
- func RegisterDeepCopies(scheme *runtime.Scheme) errordeprecated
- func Resource(resource string) schema.GroupResource
- type Client
- func (c *Client) ComponentStatuses(namespace string) ComponentStatusInterface
- func (c *Client) Endpoints(namespace string) EndpointsInterface
- func (c *Client) Events(namespace string) EventInterface
- func (c *Client) Namespaces(namespace string) NamespaceInterface
- func (c *Client) Nodes(namespace string) NodeInterface
- func (c *Client) Pods(namespace string) PodInterface
- func (c *Client) RESTClient() rest.Interface
- func (c *Client) Secrets(namespace string) SecretInterface
- func (c *Client) Services(namespace string) ServiceInterface
- func (c *Client) Start(ctx context.Context, threadiness int) error
- func (c *Client) Sync(ctx context.Context) error
- type ComponentStatusController
- type ComponentStatusHandlerFunc
- type ComponentStatusInterface
- type ComponentStatusLifecycle
- type ComponentStatusList
- type ComponentStatusLister
- type ComponentStatusesGetter
- type EndpointsController
- type EndpointsGetter
- type EndpointsHandlerFunc
- type EndpointsInterface
- type EndpointsLifecycle
- type EndpointsList
- type EndpointsLister
- type EventController
- type EventHandlerFunc
- type EventInterface
- type EventLifecycle
- type EventList
- type EventLister
- type EventsGetter
- type Interface
- type NamespaceController
- type NamespaceHandlerFunc
- type NamespaceInterface
- type NamespaceLifecycle
- type NamespaceList
- type NamespaceLister
- type NamespacesGetter
- type NodeController
- type NodeHandlerFunc
- type NodeInterface
- type NodeLifecycle
- type NodeList
- type NodeLister
- type NodesGetter
- type PodController
- type PodHandlerFunc
- type PodInterface
- type PodLifecycle
- type PodList
- type PodLister
- type PodsGetter
- type SecretController
- type SecretHandlerFunc
- type SecretInterface
- type SecretLifecycle
- type SecretList
- type SecretLister
- type SecretsGetter
- type ServiceController
- type ServiceHandlerFunc
- type ServiceInterface
- type ServiceLifecycle
- type ServiceList
- type ServiceLister
- type ServicesGetter
Constants ¶
const ( GroupName = "" Version = "v1" )
Variables ¶
var ( ComponentStatusGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "ComponentStatus", } ComponentStatusResource = metav1.APIResource{ Name: "componentstatuses", SingularName: "componentstatus", Namespaced: false, Kind: ComponentStatusGroupVersionKind.Kind, } )
var ( EndpointsGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "Endpoints", } EndpointsResource = metav1.APIResource{ Name: "endpoints", SingularName: "endpoints", Namespaced: true, Kind: EndpointsGroupVersionKind.Kind, } )
var ( EventGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "Event", } EventResource = metav1.APIResource{ Name: "events", SingularName: "event", Namespaced: false, Kind: EventGroupVersionKind.Kind, } )
var ( NamespaceGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "Namespace", } NamespaceResource = metav1.APIResource{ Name: "namespaces", SingularName: "namespace", Namespaced: false, Kind: NamespaceGroupVersionKind.Kind, } )
var ( NodeGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "Node", } NodeResource = metav1.APIResource{ Name: "nodes", SingularName: "node", Namespaced: false, Kind: NodeGroupVersionKind.Kind, } )
var ( PodGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "Pod", } PodResource = metav1.APIResource{ Name: "pods", SingularName: "pod", Namespaced: true, Kind: PodGroupVersionKind.Kind, } )
var ( SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = SchemeBuilder.AddToScheme )
var ( SecretGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "Secret", } SecretResource = metav1.APIResource{ Name: "secrets", SingularName: "secret", Namespaced: true, Kind: SecretGroupVersionKind.Kind, } )
var ( ServiceGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "Service", } ServiceResource = metav1.APIResource{ Name: "services", SingularName: "service", Namespaced: true, Kind: ServiceGroupVersionKind.Kind, } )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: Version}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func RegisterDeepCopies
deprecated
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type Client ¶
func (*Client) ComponentStatuses ¶
func (c *Client) ComponentStatuses(namespace string) ComponentStatusInterface
func (*Client) Endpoints ¶
func (c *Client) Endpoints(namespace string) EndpointsInterface
func (*Client) Events ¶
func (c *Client) Events(namespace string) EventInterface
func (*Client) Namespaces ¶
func (c *Client) Namespaces(namespace string) NamespaceInterface
func (*Client) Nodes ¶
func (c *Client) Nodes(namespace string) NodeInterface
func (*Client) Pods ¶
func (c *Client) Pods(namespace string) PodInterface
func (*Client) RESTClient ¶
func (*Client) Secrets ¶
func (c *Client) Secrets(namespace string) SecretInterface
func (*Client) Services ¶
func (c *Client) Services(namespace string) ServiceInterface
type ComponentStatusController ¶
type ComponentStatusController interface {
Informer() cache.SharedIndexInformer
Lister() ComponentStatusLister
AddHandler(name string, handler ComponentStatusHandlerFunc)
AddClusterScopedHandler(name, clusterName string, handler ComponentStatusHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type ComponentStatusHandlerFunc ¶
func NewComponentStatusLifecycleAdapter ¶
func NewComponentStatusLifecycleAdapter(name string, clusterScoped bool, client ComponentStatusInterface, l ComponentStatusLifecycle) ComponentStatusHandlerFunc
type ComponentStatusInterface ¶
type ComponentStatusInterface interface {
ObjectClient() *clientbase.ObjectClient
Create(*v1.ComponentStatus) (*v1.ComponentStatus, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.ComponentStatus, error)
Get(name string, opts metav1.GetOptions) (*v1.ComponentStatus, error)
Update(*v1.ComponentStatus) (*v1.ComponentStatus, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*ComponentStatusList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() ComponentStatusController
AddHandler(name string, sync ComponentStatusHandlerFunc)
AddLifecycle(name string, lifecycle ComponentStatusLifecycle)
AddClusterScopedHandler(name, clusterName string, sync ComponentStatusHandlerFunc)
AddClusterScopedLifecycle(name, clusterName string, lifecycle ComponentStatusLifecycle)
}
type ComponentStatusList ¶
type ComponentStatusList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.ComponentStatus
}
func (*ComponentStatusList) DeepCopy ¶
func (in *ComponentStatusList) DeepCopy() *ComponentStatusList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ComponentStatusList.
func (*ComponentStatusList) DeepCopyInto ¶
func (in *ComponentStatusList) DeepCopyInto(out *ComponentStatusList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ComponentStatusList) DeepCopyObject ¶
func (in *ComponentStatusList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ComponentStatusLister ¶
type ComponentStatusesGetter ¶
type ComponentStatusesGetter interface {
ComponentStatuses(namespace string) ComponentStatusInterface
}
type EndpointsController ¶
type EndpointsController interface {
Informer() cache.SharedIndexInformer
Lister() EndpointsLister
AddHandler(name string, handler EndpointsHandlerFunc)
AddClusterScopedHandler(name, clusterName string, handler EndpointsHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type EndpointsGetter ¶
type EndpointsGetter interface {
Endpoints(namespace string) EndpointsInterface
}
type EndpointsHandlerFunc ¶
func NewEndpointsLifecycleAdapter ¶
func NewEndpointsLifecycleAdapter(name string, clusterScoped bool, client EndpointsInterface, l EndpointsLifecycle) EndpointsHandlerFunc
type EndpointsInterface ¶
type EndpointsInterface interface {
ObjectClient() *clientbase.ObjectClient
Create(*v1.Endpoints) (*v1.Endpoints, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.Endpoints, error)
Get(name string, opts metav1.GetOptions) (*v1.Endpoints, error)
Update(*v1.Endpoints) (*v1.Endpoints, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*EndpointsList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() EndpointsController
AddHandler(name string, sync EndpointsHandlerFunc)
AddLifecycle(name string, lifecycle EndpointsLifecycle)
AddClusterScopedHandler(name, clusterName string, sync EndpointsHandlerFunc)
AddClusterScopedLifecycle(name, clusterName string, lifecycle EndpointsLifecycle)
}
type EndpointsLifecycle ¶
type EndpointsList ¶
type EndpointsList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.Endpoints
}
func (*EndpointsList) DeepCopy ¶
func (in *EndpointsList) DeepCopy() *EndpointsList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EndpointsList.
func (*EndpointsList) DeepCopyInto ¶
func (in *EndpointsList) DeepCopyInto(out *EndpointsList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EndpointsList) DeepCopyObject ¶
func (in *EndpointsList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type EndpointsLister ¶
type EventController ¶
type EventController interface {
Informer() cache.SharedIndexInformer
Lister() EventLister
AddHandler(name string, handler EventHandlerFunc)
AddClusterScopedHandler(name, clusterName string, handler EventHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type EventHandlerFunc ¶
func NewEventLifecycleAdapter ¶
func NewEventLifecycleAdapter(name string, clusterScoped bool, client EventInterface, l EventLifecycle) EventHandlerFunc
type EventInterface ¶
type EventInterface interface {
ObjectClient() *clientbase.ObjectClient
Create(*v1.Event) (*v1.Event, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.Event, error)
Get(name string, opts metav1.GetOptions) (*v1.Event, error)
Update(*v1.Event) (*v1.Event, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*EventList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() EventController
AddHandler(name string, sync EventHandlerFunc)
AddLifecycle(name string, lifecycle EventLifecycle)
AddClusterScopedHandler(name, clusterName string, sync EventHandlerFunc)
AddClusterScopedLifecycle(name, clusterName string, lifecycle EventLifecycle)
}
type EventLifecycle ¶
type EventList ¶
type EventList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.Event
}
func (*EventList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EventList.
func (*EventList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EventList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type EventLister ¶
type EventsGetter ¶
type EventsGetter interface {
Events(namespace string) EventInterface
}
type Interface ¶
type Interface interface {
RESTClient() rest.Interface
controller.Starter
NodesGetter
ComponentStatusesGetter
NamespacesGetter
EventsGetter
EndpointsGetter
PodsGetter
ServicesGetter
SecretsGetter
}
type NamespaceController ¶
type NamespaceController interface {
Informer() cache.SharedIndexInformer
Lister() NamespaceLister
AddHandler(name string, handler NamespaceHandlerFunc)
AddClusterScopedHandler(name, clusterName string, handler NamespaceHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type NamespaceHandlerFunc ¶
func NewNamespaceLifecycleAdapter ¶
func NewNamespaceLifecycleAdapter(name string, clusterScoped bool, client NamespaceInterface, l NamespaceLifecycle) NamespaceHandlerFunc
type NamespaceInterface ¶
type NamespaceInterface interface {
ObjectClient() *clientbase.ObjectClient
Create(*v1.Namespace) (*v1.Namespace, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.Namespace, error)
Get(name string, opts metav1.GetOptions) (*v1.Namespace, error)
Update(*v1.Namespace) (*v1.Namespace, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*NamespaceList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() NamespaceController
AddHandler(name string, sync NamespaceHandlerFunc)
AddLifecycle(name string, lifecycle NamespaceLifecycle)
AddClusterScopedHandler(name, clusterName string, sync NamespaceHandlerFunc)
AddClusterScopedLifecycle(name, clusterName string, lifecycle NamespaceLifecycle)
}
type NamespaceLifecycle ¶
type NamespaceList ¶
type NamespaceList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.Namespace
}
func (*NamespaceList) DeepCopy ¶
func (in *NamespaceList) DeepCopy() *NamespaceList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NamespaceList.
func (*NamespaceList) DeepCopyInto ¶
func (in *NamespaceList) DeepCopyInto(out *NamespaceList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*NamespaceList) DeepCopyObject ¶
func (in *NamespaceList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type NamespaceLister ¶
type NamespacesGetter ¶
type NamespacesGetter interface {
Namespaces(namespace string) NamespaceInterface
}
type NodeController ¶
type NodeController interface {
Informer() cache.SharedIndexInformer
Lister() NodeLister
AddHandler(name string, handler NodeHandlerFunc)
AddClusterScopedHandler(name, clusterName string, handler NodeHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type NodeHandlerFunc ¶
func NewNodeLifecycleAdapter ¶
func NewNodeLifecycleAdapter(name string, clusterScoped bool, client NodeInterface, l NodeLifecycle) NodeHandlerFunc
type NodeInterface ¶
type NodeInterface interface {
ObjectClient() *clientbase.ObjectClient
Create(*v1.Node) (*v1.Node, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.Node, error)
Get(name string, opts metav1.GetOptions) (*v1.Node, error)
Update(*v1.Node) (*v1.Node, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*NodeList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() NodeController
AddHandler(name string, sync NodeHandlerFunc)
AddLifecycle(name string, lifecycle NodeLifecycle)
AddClusterScopedHandler(name, clusterName string, sync NodeHandlerFunc)
AddClusterScopedLifecycle(name, clusterName string, lifecycle NodeLifecycle)
}
type NodeLifecycle ¶
type NodeList ¶
type NodeList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.Node
}
func (*NodeList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NodeList.
func (*NodeList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*NodeList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type NodeLister ¶
type NodesGetter ¶
type NodesGetter interface {
Nodes(namespace string) NodeInterface
}
type PodController ¶
type PodController interface {
Informer() cache.SharedIndexInformer
Lister() PodLister
AddHandler(name string, handler PodHandlerFunc)
AddClusterScopedHandler(name, clusterName string, handler PodHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type PodHandlerFunc ¶
func NewPodLifecycleAdapter ¶
func NewPodLifecycleAdapter(name string, clusterScoped bool, client PodInterface, l PodLifecycle) PodHandlerFunc
type PodInterface ¶
type PodInterface interface {
ObjectClient() *clientbase.ObjectClient
Create(*v1.Pod) (*v1.Pod, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.Pod, error)
Get(name string, opts metav1.GetOptions) (*v1.Pod, error)
Update(*v1.Pod) (*v1.Pod, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*PodList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() PodController
AddHandler(name string, sync PodHandlerFunc)
AddLifecycle(name string, lifecycle PodLifecycle)
AddClusterScopedHandler(name, clusterName string, sync PodHandlerFunc)
AddClusterScopedLifecycle(name, clusterName string, lifecycle PodLifecycle)
}
type PodLifecycle ¶
type PodList ¶
type PodList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.Pod
}
func (*PodList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PodList.
func (*PodList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PodList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PodsGetter ¶
type PodsGetter interface {
Pods(namespace string) PodInterface
}
type SecretController ¶
type SecretController interface {
Informer() cache.SharedIndexInformer
Lister() SecretLister
AddHandler(name string, handler SecretHandlerFunc)
AddClusterScopedHandler(name, clusterName string, handler SecretHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type SecretHandlerFunc ¶
func NewSecretLifecycleAdapter ¶
func NewSecretLifecycleAdapter(name string, clusterScoped bool, client SecretInterface, l SecretLifecycle) SecretHandlerFunc
type SecretInterface ¶
type SecretInterface interface {
ObjectClient() *clientbase.ObjectClient
Create(*v1.Secret) (*v1.Secret, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.Secret, error)
Get(name string, opts metav1.GetOptions) (*v1.Secret, error)
Update(*v1.Secret) (*v1.Secret, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*SecretList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() SecretController
AddHandler(name string, sync SecretHandlerFunc)
AddLifecycle(name string, lifecycle SecretLifecycle)
AddClusterScopedHandler(name, clusterName string, sync SecretHandlerFunc)
AddClusterScopedLifecycle(name, clusterName string, lifecycle SecretLifecycle)
}
type SecretLifecycle ¶
type SecretList ¶
type SecretList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.Secret
}
func (*SecretList) DeepCopy ¶
func (in *SecretList) DeepCopy() *SecretList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SecretList.
func (*SecretList) DeepCopyInto ¶
func (in *SecretList) DeepCopyInto(out *SecretList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*SecretList) DeepCopyObject ¶
func (in *SecretList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type SecretLister ¶
type SecretsGetter ¶
type SecretsGetter interface {
Secrets(namespace string) SecretInterface
}
type ServiceController ¶
type ServiceController interface {
Informer() cache.SharedIndexInformer
Lister() ServiceLister
AddHandler(name string, handler ServiceHandlerFunc)
AddClusterScopedHandler(name, clusterName string, handler ServiceHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type ServiceHandlerFunc ¶
func NewServiceLifecycleAdapter ¶
func NewServiceLifecycleAdapter(name string, clusterScoped bool, client ServiceInterface, l ServiceLifecycle) ServiceHandlerFunc
type ServiceInterface ¶
type ServiceInterface interface {
ObjectClient() *clientbase.ObjectClient
Create(*v1.Service) (*v1.Service, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.Service, error)
Get(name string, opts metav1.GetOptions) (*v1.Service, error)
Update(*v1.Service) (*v1.Service, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*ServiceList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() ServiceController
AddHandler(name string, sync ServiceHandlerFunc)
AddLifecycle(name string, lifecycle ServiceLifecycle)
AddClusterScopedHandler(name, clusterName string, sync ServiceHandlerFunc)
AddClusterScopedLifecycle(name, clusterName string, lifecycle ServiceLifecycle)
}
type ServiceLifecycle ¶
type ServiceList ¶
type ServiceList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.Service
}
func (*ServiceList) DeepCopy ¶
func (in *ServiceList) DeepCopy() *ServiceList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ServiceList.
func (*ServiceList) DeepCopyInto ¶
func (in *ServiceList) DeepCopyInto(out *ServiceList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ServiceList) DeepCopyObject ¶
func (in *ServiceList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ServiceLister ¶
type ServicesGetter ¶
type ServicesGetter interface {
Services(namespace string) ServiceInterface
}
Source Files
¶
- zz_generated_component_status_controller.go
- zz_generated_component_status_lifecycle_adapter.go
- zz_generated_deepcopy.go
- zz_generated_endpoints_controller.go
- zz_generated_endpoints_lifecycle_adapter.go
- zz_generated_event_controller.go
- zz_generated_event_lifecycle_adapter.go
- zz_generated_k8s_client.go
- zz_generated_namespace_controller.go
- zz_generated_namespace_lifecycle_adapter.go
- zz_generated_node_controller.go
- zz_generated_node_lifecycle_adapter.go
- zz_generated_pod_controller.go
- zz_generated_pod_lifecycle_adapter.go
- zz_generated_scheme.go
- zz_generated_secret_controller.go
- zz_generated_secret_lifecycle_adapter.go
- zz_generated_service_controller.go
- zz_generated_service_lifecycle_adapter.go