Documentation
¶
Index ¶
- Constants
- Variables
- func Kind(kind string) schema.GroupKind
- func RegisterDeepCopies(scheme *runtime.Scheme) errordeprecated
- func Resource(resource string) schema.GroupResource
- type Client
- func (c *Client) ClusterRoleBindings(namespace string) ClusterRoleBindingInterface
- func (c *Client) ClusterRoles(namespace string) ClusterRoleInterface
- func (c *Client) RESTClient() rest.Interface
- func (c *Client) RoleBindings(namespace string) RoleBindingInterface
- func (c *Client) Roles(namespace string) RoleInterface
- func (c *Client) Start(ctx context.Context, threadiness int) error
- func (c *Client) Sync(ctx context.Context) error
- type ClusterRoleBindingController
- type ClusterRoleBindingHandlerFunc
- type ClusterRoleBindingInterface
- type ClusterRoleBindingLifecycle
- type ClusterRoleBindingList
- type ClusterRoleBindingLister
- type ClusterRoleBindingsGetter
- type ClusterRoleController
- type ClusterRoleHandlerFunc
- type ClusterRoleInterface
- type ClusterRoleLifecycle
- type ClusterRoleList
- type ClusterRoleLister
- type ClusterRolesGetter
- type Interface
- type RoleBindingController
- type RoleBindingHandlerFunc
- type RoleBindingInterface
- type RoleBindingLifecycle
- type RoleBindingList
- type RoleBindingLister
- type RoleBindingsGetter
- type RoleController
- type RoleHandlerFunc
- type RoleInterface
- type RoleLifecycle
- type RoleList
- type RoleLister
- type RolesGetter
Constants ¶
const ( GroupName = "rbac.authorization.k8s.io" Version = "v1" )
Variables ¶
var ( ClusterRoleBindingGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "ClusterRoleBinding", } ClusterRoleBindingResource = metav1.APIResource{ Name: "clusterrolebindings", SingularName: "clusterrolebinding", Namespaced: false, Kind: ClusterRoleBindingGroupVersionKind.Kind, } )
var ( ClusterRoleGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "ClusterRole", } ClusterRoleResource = metav1.APIResource{ Name: "clusterroles", SingularName: "clusterrole", Namespaced: false, Kind: ClusterRoleGroupVersionKind.Kind, } )
var ( RoleBindingGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "RoleBinding", } RoleBindingResource = metav1.APIResource{ Name: "rolebindings", SingularName: "rolebinding", Namespaced: true, Kind: RoleBindingGroupVersionKind.Kind, } )
var ( RoleGroupVersionKind = schema.GroupVersionKind{ Version: Version, Group: GroupName, Kind: "Role", } RoleResource = metav1.APIResource{ Name: "roles", SingularName: "role", Namespaced: true, Kind: RoleGroupVersionKind.Kind, } )
var ( SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: Version}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func RegisterDeepCopies
deprecated
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type Client ¶
func (*Client) ClusterRoleBindings ¶
func (c *Client) ClusterRoleBindings(namespace string) ClusterRoleBindingInterface
func (*Client) ClusterRoles ¶
func (c *Client) ClusterRoles(namespace string) ClusterRoleInterface
func (*Client) RESTClient ¶
func (*Client) RoleBindings ¶
func (c *Client) RoleBindings(namespace string) RoleBindingInterface
func (*Client) Roles ¶
func (c *Client) Roles(namespace string) RoleInterface
type ClusterRoleBindingController ¶
type ClusterRoleBindingController interface {
Informer() cache.SharedIndexInformer
Lister() ClusterRoleBindingLister
AddHandler(name string, handler ClusterRoleBindingHandlerFunc)
AddClusterScopedHandler(name, clusterName string, handler ClusterRoleBindingHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type ClusterRoleBindingHandlerFunc ¶
func NewClusterRoleBindingLifecycleAdapter ¶
func NewClusterRoleBindingLifecycleAdapter(name string, clusterScoped bool, client ClusterRoleBindingInterface, l ClusterRoleBindingLifecycle) ClusterRoleBindingHandlerFunc
type ClusterRoleBindingInterface ¶
type ClusterRoleBindingInterface interface {
ObjectClient() *clientbase.ObjectClient
Create(*v1.ClusterRoleBinding) (*v1.ClusterRoleBinding, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.ClusterRoleBinding, error)
Get(name string, opts metav1.GetOptions) (*v1.ClusterRoleBinding, error)
Update(*v1.ClusterRoleBinding) (*v1.ClusterRoleBinding, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*ClusterRoleBindingList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() ClusterRoleBindingController
AddHandler(name string, sync ClusterRoleBindingHandlerFunc)
AddLifecycle(name string, lifecycle ClusterRoleBindingLifecycle)
AddClusterScopedHandler(name, clusterName string, sync ClusterRoleBindingHandlerFunc)
AddClusterScopedLifecycle(name, clusterName string, lifecycle ClusterRoleBindingLifecycle)
}
type ClusterRoleBindingList ¶
type ClusterRoleBindingList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.ClusterRoleBinding
}
func (*ClusterRoleBindingList) DeepCopy ¶
func (in *ClusterRoleBindingList) DeepCopy() *ClusterRoleBindingList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterRoleBindingList.
func (*ClusterRoleBindingList) DeepCopyInto ¶
func (in *ClusterRoleBindingList) DeepCopyInto(out *ClusterRoleBindingList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ClusterRoleBindingList) DeepCopyObject ¶
func (in *ClusterRoleBindingList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ClusterRoleBindingsGetter ¶
type ClusterRoleBindingsGetter interface {
ClusterRoleBindings(namespace string) ClusterRoleBindingInterface
}
type ClusterRoleController ¶
type ClusterRoleController interface {
Informer() cache.SharedIndexInformer
Lister() ClusterRoleLister
AddHandler(name string, handler ClusterRoleHandlerFunc)
AddClusterScopedHandler(name, clusterName string, handler ClusterRoleHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type ClusterRoleHandlerFunc ¶
func NewClusterRoleLifecycleAdapter ¶
func NewClusterRoleLifecycleAdapter(name string, clusterScoped bool, client ClusterRoleInterface, l ClusterRoleLifecycle) ClusterRoleHandlerFunc
type ClusterRoleInterface ¶
type ClusterRoleInterface interface {
ObjectClient() *clientbase.ObjectClient
Create(*v1.ClusterRole) (*v1.ClusterRole, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.ClusterRole, error)
Get(name string, opts metav1.GetOptions) (*v1.ClusterRole, error)
Update(*v1.ClusterRole) (*v1.ClusterRole, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*ClusterRoleList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() ClusterRoleController
AddHandler(name string, sync ClusterRoleHandlerFunc)
AddLifecycle(name string, lifecycle ClusterRoleLifecycle)
AddClusterScopedHandler(name, clusterName string, sync ClusterRoleHandlerFunc)
AddClusterScopedLifecycle(name, clusterName string, lifecycle ClusterRoleLifecycle)
}
type ClusterRoleLifecycle ¶
type ClusterRoleList ¶
type ClusterRoleList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.ClusterRole
}
func (*ClusterRoleList) DeepCopy ¶
func (in *ClusterRoleList) DeepCopy() *ClusterRoleList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterRoleList.
func (*ClusterRoleList) DeepCopyInto ¶
func (in *ClusterRoleList) DeepCopyInto(out *ClusterRoleList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ClusterRoleList) DeepCopyObject ¶
func (in *ClusterRoleList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ClusterRoleLister ¶
type ClusterRolesGetter ¶
type ClusterRolesGetter interface {
ClusterRoles(namespace string) ClusterRoleInterface
}
type Interface ¶
type Interface interface {
RESTClient() rest.Interface
controller.Starter
ClusterRoleBindingsGetter
ClusterRolesGetter
RoleBindingsGetter
RolesGetter
}
type RoleBindingController ¶
type RoleBindingController interface {
Informer() cache.SharedIndexInformer
Lister() RoleBindingLister
AddHandler(name string, handler RoleBindingHandlerFunc)
AddClusterScopedHandler(name, clusterName string, handler RoleBindingHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type RoleBindingHandlerFunc ¶
func NewRoleBindingLifecycleAdapter ¶
func NewRoleBindingLifecycleAdapter(name string, clusterScoped bool, client RoleBindingInterface, l RoleBindingLifecycle) RoleBindingHandlerFunc
type RoleBindingInterface ¶
type RoleBindingInterface interface {
ObjectClient() *clientbase.ObjectClient
Create(*v1.RoleBinding) (*v1.RoleBinding, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.RoleBinding, error)
Get(name string, opts metav1.GetOptions) (*v1.RoleBinding, error)
Update(*v1.RoleBinding) (*v1.RoleBinding, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*RoleBindingList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() RoleBindingController
AddHandler(name string, sync RoleBindingHandlerFunc)
AddLifecycle(name string, lifecycle RoleBindingLifecycle)
AddClusterScopedHandler(name, clusterName string, sync RoleBindingHandlerFunc)
AddClusterScopedLifecycle(name, clusterName string, lifecycle RoleBindingLifecycle)
}
type RoleBindingLifecycle ¶
type RoleBindingList ¶
type RoleBindingList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.RoleBinding
}
func (*RoleBindingList) DeepCopy ¶
func (in *RoleBindingList) DeepCopy() *RoleBindingList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RoleBindingList.
func (*RoleBindingList) DeepCopyInto ¶
func (in *RoleBindingList) DeepCopyInto(out *RoleBindingList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*RoleBindingList) DeepCopyObject ¶
func (in *RoleBindingList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type RoleBindingLister ¶
type RoleBindingsGetter ¶
type RoleBindingsGetter interface {
RoleBindings(namespace string) RoleBindingInterface
}
type RoleController ¶
type RoleController interface {
Informer() cache.SharedIndexInformer
Lister() RoleLister
AddHandler(name string, handler RoleHandlerFunc)
AddClusterScopedHandler(name, clusterName string, handler RoleHandlerFunc)
Enqueue(namespace, name string)
Sync(ctx context.Context) error
Start(ctx context.Context, threadiness int) error
}
type RoleHandlerFunc ¶
func NewRoleLifecycleAdapter ¶
func NewRoleLifecycleAdapter(name string, clusterScoped bool, client RoleInterface, l RoleLifecycle) RoleHandlerFunc
type RoleInterface ¶
type RoleInterface interface {
ObjectClient() *clientbase.ObjectClient
Create(*v1.Role) (*v1.Role, error)
GetNamespaced(namespace, name string, opts metav1.GetOptions) (*v1.Role, error)
Get(name string, opts metav1.GetOptions) (*v1.Role, error)
Update(*v1.Role) (*v1.Role, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteNamespaced(namespace, name string, options *metav1.DeleteOptions) error
List(opts metav1.ListOptions) (*RoleList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
DeleteCollection(deleteOpts *metav1.DeleteOptions, listOpts metav1.ListOptions) error
Controller() RoleController
AddHandler(name string, sync RoleHandlerFunc)
AddLifecycle(name string, lifecycle RoleLifecycle)
AddClusterScopedHandler(name, clusterName string, sync RoleHandlerFunc)
AddClusterScopedLifecycle(name, clusterName string, lifecycle RoleLifecycle)
}
type RoleLifecycle ¶
type RoleList ¶
type RoleList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []v1.Role
}
func (*RoleList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RoleList.
func (*RoleList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*RoleList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type RoleLister ¶
type RolesGetter ¶
type RolesGetter interface {
Roles(namespace string) RoleInterface
}
Source Files
¶
- zz_generated_cluster_role_binding_controller.go
- zz_generated_cluster_role_binding_lifecycle_adapter.go
- zz_generated_cluster_role_controller.go
- zz_generated_cluster_role_lifecycle_adapter.go
- zz_generated_deepcopy.go
- zz_generated_k8s_client.go
- zz_generated_role_binding_controller.go
- zz_generated_role_binding_lifecycle_adapter.go
- zz_generated_role_controller.go
- zz_generated_role_lifecycle_adapter.go
- zz_generated_scheme.go